]> git.rkrishnan.org Git - .emacs.d.git/commitdiff
intero instead of ghc-mod
authorRamakrishnan Muthukrishnan <ram@rkrishnan.org>
Fri, 22 Jul 2016 05:56:44 +0000 (11:26 +0530)
committerRamakrishnan Muthukrishnan <ram@rkrishnan.org>
Fri, 22 Jul 2016 05:56:44 +0000 (11:26 +0530)
init.el

diff --git a/init.el b/init.el
index 325d2ff0af30c4e5bf71da7ca1ec912f131d7589..7cdcceedf84b1c8c4949677e3e94667d6e73033e 100644 (file)
--- a/init.el
+++ b/init.el
@@ -56,7 +56,7 @@
 (setq erc-autojoin-channels-alist
       '((".*\\.freenode.net" "#tahoe-lafs")
         (".*\\.oftc.net" "#LeastAuthority")
-        (".*\\.mozilla.org" "#rust-beginners")
+        ;; (".*\\.mozilla.org" "#rust-beginners")
         ))
 
 ;; check channels
   "Connect to IRC."
   (interactive)
   (when (y-or-n-p "Do you want to start IRC? ")
-    (erc-tls :server "irc.mozilla.org" :port 6697 :nick "rkrishnan" :full-name "Ramakrishnan Muthukrishnan")
+    ;; (erc-tls :server "irc.mozilla.org" :port 6697 :nick "rkrishnan" :full-name "Ramakrishnan Muthukrishnan")
     (erc-tls :server "irc.freenode.net" :port 6697 :nick "rkrishnan" :full-name "Ramakrishnan Muthukrishnan")
     (erc-tls :server "irc.oftc.net" :port 6697 :nick "rkrishnan" :full-name "Ramakrishnan Muthukrishnan")))
 
 ;; switch to ERC with Ctrl+c e
 (global-set-key (kbd "C-c e") 'start-erc) ;; ERC
 
-;; haskell mode
-(setenv "PATH" (concat "~/.cabal/bin:" (getenv "PATH")))
-(add-to-list 'exec-path "~/.cabal/bin")
-(add-hook 'haskell-mode-hook 'turn-on-haskell-doc-mode)
-
-;; haskell mode
-(require 'haskell-process)
-(require 'haskell-interactive-mode)
-(add-hook 'haskell-mode-hook 'interactive-haskell-mode)
-
-(custom-set-variables
-  '(haskell-process-suggest-remove-import-lines t)
-  '(haskell-process-auto-import-loaded-modules t)
-  '(haskell-process-log t)
-  '(haskell-process-type 'stack-ghci))
-
-(define-key haskell-mode-map (kbd "C-c C-l") 'haskell-process-load-or-reload)
-(define-key haskell-mode-map (kbd "C-`") 'haskell-interactive-bring)
-(define-key haskell-mode-map (kbd "C-c C-t") 'haskell-process-do-type)
-(define-key haskell-mode-map (kbd "C-c C-i") 'haskell-process-do-info)
-(define-key haskell-mode-map (kbd "C-c C-c") 'haskell-process-cabal-build)
-(define-key haskell-mode-map (kbd "C-c C-k") 'haskell-interactive-mode-clear)
-(define-key haskell-mode-map (kbd "C-c c") 'haskell-process-cabal)
-(define-key haskell-mode-map (kbd "SPC") 'haskell-mode-contextual-space)
-
-;; ghc-mod
-(autoload 'ghc-init "ghc" nil t)
-(autoload 'ghc-debug "ghc" nil t)
-(setq ghc-debug t)
-(add-hook 'haskell-mode-hook (lambda () (ghc-init)))
+;; Haskell intero mode
+(add-hook 'haskell-mode-hook 'intero-mode)
 
 ;; ido
 (setq ido-enable-flex-matching t)